========
otpstore
========


.. image:: https://img.shields.io/pypi/v/otpstore.svg
        :target: https://pypi.python.org/pypi/otpstore

.. image:: https://img.shields.io/travis/suryasankar/otpstore.svg
        :target: https://travis-ci.com/suryasankar/otpstore

.. image:: https://readthedocs.org/projects/otpstore/badge/?version=latest
        :target: https://otpstore.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A python package for generating otp keys, storing them in redis and verifying them


* Free software: MIT license
* Documentation: https://otpstore.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
